/* filenameEntry.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"

#include "filenameEntry.h"

#define XK_MISCELLANY
#include <X11/keysymdef.h>

FilenameEntry::
FilenameEntry() : 
  _browse_button("Browse") 
{
  _dialog = (Gtk_FileSelection *)NULL;
  
  layout_window();
}

FilenameEntry::
~FilenameEntry() {
  delete_dialog();
}

void FilenameEntry::
set_filename(const string &filename) {
  _entry.set_text(filename);
}

string FilenameEntry::
get_filename() {
  return _entry.get_text();
}

void FilenameEntry::
popup_dialog() {
  delete_dialog();
  _dialog = new Gtk_FileSelection(get_filename());
  connect_to_method(_dialog->destroy, this, &dialog_deleted);
  connect_to_method(_dialog->get_ok_button()->clicked, this, &dialog_accepted);
  connect_to_method(_dialog->get_cancel_button()->clicked, this, &delete_dialog);
  _dialog->show();
}

void FilenameEntry::
delete_dialog() {
  if (_dialog != NULL) {
    _dialog->hide();
    delete _dialog;
    _dialog = (Gtk_FileSelection *)NULL;
  }
}

void FilenameEntry::
browse_button_clicked() {
  popup_dialog();
}

void FilenameEntry::
entry_activated() {
  activate();
}

gint FilenameEntry::
entry_keypress(GdkEventKey *p1) {
  switch (p1->keyval) {
  case XK_F1:
    // F1 : Browse filename.
    popup_dialog();
    return true;
  }

  return false;
}

// Called on return from the FilenameDialog, created via popup_dialog().
void FilenameEntry::
dialog_accepted() {
  set_filename(_dialog->get_filename());
  delete_dialog();
}

void FilenameEntry::
dialog_deleted() {
  _dialog = (Gtk_FileSelection *)NULL;
}


void FilenameEntry::
layout_window() {
  pack_start(_entry, true, true, 0);
  _entry.show();
  connect_to_method(_entry.activate, this, &entry_activated);
  connect_to_method(_entry.key_press_event, this, &entry_keypress);

  pack_start(_browse_button, false, false, 4);
  _browse_button.set_usize(72, 24);
  _browse_button.show();
  connect_to_method(_browse_button.clicked, this, &browse_button_clicked);
}
