/* palomaDialog.h

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#ifndef PALOMADIALOG_H
#define PALOMADIALOG_H

#include "dataset.h"

#include <gtk--.h>
#include <set>

// This class is the base class for all dialog windows created for
// Paloma.  It mainly defines the setup() function, which does things
// like make an icon and add a hook to the destroyed signal.

class PalomaDialog : public Gtk_Dialog {
public:
  PalomaDialog(const Dataset &data);
  virtual ~PalomaDialog();
  void setup();

  void add_child_dialog(PalomaDialog *dialog);

  virtual void record_db();
  const Dataset &get_data() const;
  
  Signal0 deleted;
  Signal0 accepted;

protected:
  Dataset _data;

  // We keep a set of all the child dialogs we've currently got open,
  // so that when the dialog is deleted it can delete these too.
  typedef set<PalomaDialog *> Dialogs;
  Dialogs _child_dialogs;

private:
  void got_child_dialog_delete(PalomaDialog *dialog);
  void window_destroyed();

  Gtk_Pixmap _icon_pixmap;
  Gtk_Window _icon_window;
  bool _destroyed;
};

#endif

